pub struct RawMatch {
pub start: usize,
pub finish: usize,
pub captures: Vec<(String, String)>,
}Expand description
One match found by a MatchParser, in coordinates relative to the
scanned text (add the scan offset for absolute positions).
Fields
start: usizeByte offset of the match start, relative to the scanned text.
finish: usizeByte offset just past the match, relative to the scanned text.
captures: Vec<(String, String)>Free-form capture data: named groups for templates and callbacks.
Implementations